@@ -31,16 +31,19 @@ def qry2df(qry, constr=None):
     try:
         df = []
         hdr = []
+        rows = None
 
         log(str(type(constr)))
         con = psycopg2.connect(**constr)
         cur = con.cursor()
         cur.execute(qry)
-        rows = cur.fetchall()
+        try:
+            rows = cur.fetchall()
+        except:
+            con.commit()
         if rows:
             for cn in cur.description:
                 hdr.append(cn[0])
-        con.commit()
         con.close()
         if rows:
             df.append(hdr)
